package intel_hex

  1. Overview
  2. Docs

intel_hex

API

Library intel_hex

  • Intel_hex A Intel HEX manipulation library for parsing and generating Intel HEX (also known as IHEX) objects. This format is commonly used to represent compiled program code and data that is loaded into a microcontroller, flash memory, or ROM in embedded systems programming.