Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
intel_hex
The Intel HEX manipulation library for OCaml provides functions to read, write, and create Intel HEX format data, which is commonly used in embedded systems programming.
Usage
If you are using Dune, add the intel_hex library to your libraries stanza.
Here is an example that creates an IHEX object file with test data and then prints it:
let ihex =
Intel_hex.Record.
[
Data { offset = 0; payload = "hello " };
Data { offset = 7; payload = "world" };
End_of_file
]
let () = ihex |> Intel_hex.to_string |> print_endline
Also, you can of course read the IHEX object file from other sources: